@@ -1,12 +1,12 @@
 package File::Sticker::Database;
-$File::Sticker::Database::VERSION = '1.01';
+$File::Sticker::Database::VERSION = '1.0603';
 =head1 NAME
 
 File::Sticker::Database - write info to database
 
 =head1 VERSION
 
-version 1.01
+version 1.0603
 
 =head1 SYNOPSIS
 
@@ -481,7 +481,7 @@ sub query_by_tags ($$$) {
         )
     );
 
-    printf "Q='%s'\n", $query_string if $self->{verbose} > 1;
+    say sprintf("Q='%s'", $query_string) if $self->{verbose} > 1;
     my @pfields = qw(fileid file);
     push @pfields, @{$self->{field_order}},
     push @pfields, 'faceted_tags' if $using_info_table;
@@ -513,6 +513,11 @@ sub query_by_tags ($$$) {
                        }
                        else
                        {
+                           # Fix embeddeds quotes for SQL quoting
+                           # Can't use the "quote" method because that
+                           # also puts quotes around the whole thing, which
+                           # messes things up.
+                           $term =~ s/\'/''/g;
                            push @newterms, $term; # term alone
                            push @newterms, $term . '|*'; # at start
                            push @newterms, '*|' . $term . '|*'; # in middle
@@ -522,7 +527,6 @@ sub query_by_tags ($$$) {
                    }
                    return ($term);
                }
-
         );
     my $query  = $parser->parse($query_string);
 
