@@ -1,12 +1,12 @@
 package File::Sticker::Reader::Mp3;
-$File::Sticker::Reader::Mp3::VERSION = '1.01';
+$File::Sticker::Reader::Mp3::VERSION = '1.0603';
 =head1 NAME
 
 File::Sticker::Reader::Mp3 - read and standardize meta-data from MP3 file
 
 =head1 VERSION
 
-version 1.01
+version 1.0603
 
 =head1 SYNOPSIS
 
@@ -41,6 +41,17 @@ sub whoami  { ( caller(1) )[3] }
 
 =head1 METHODS
 
+=head2 priority
+
+The priority of this reader.  Readers with higher priority get tried first.
+
+=cut
+
+sub priority {
+    my $class = shift;
+    return 2;
+} # priority
+
 =head2 allowed_file
 
 If this reader can be used for the given file, then this returns true.
