@@ -1,12 +1,12 @@
 package File::Sticker::Writer::YamlPrefix;
-$File::Sticker::Writer::YamlPrefix::VERSION = '1.01';
+$File::Sticker::Writer::YamlPrefix::VERSION = '1.0603';
 =head1 NAME
 
 File::Sticker::Writer::YamlPrefix - write and standardize meta-data from YAML file
 
 =head1 VERSION
 
-version 1.01
+version 1.0603
 
 =head1 SYNOPSIS
 
@@ -42,6 +42,17 @@ sub whoami  { ( caller(1) )[3] }
 
 =head1 METHODS
 
+=head2 priority
+
+The priority of this writer.  Writers with higher priority get tried first.
+
+=cut
+
+sub priority {
+    my $class = shift;
+    return 1;
+} # priority
+
 =head2 allowed_file
 
 If this writer can be used for the given file, then this returns true.
@@ -165,10 +176,6 @@ sub replace_all_meta {
     
 } # replace_all_meta
 
-=head1 Helper Functions
-
-Private interface.
-
 =head2 replace_one_field
 
 Overwrite the given field. This does no checking.
@@ -191,9 +198,9 @@ sub replace_one_field {
     $self->_write_meta(filename=>$filename,meta=>$info);
 } # replace_one_field
 
-=head1 Private Helper Functions
+=head1 Helper Functions
 
-Even more private interface (only within this file)
+Private interface.
 
 =head2 _has_yaml
 
